@@ -1,9 +1,9 @@
 import pandas as pd
 from numpy import dtype
-from sqlalchemy.types import Boolean, DateTime, Float, Integer, String
+from sqlalchemy.types import Boolean, DateTime, Integer, String, Numeric, BigInteger
 import os
+import sys
 import logging
-import tempfile
 from df_to_azure.adf import create_blob_service_client
 import df_to_azure.adf as adf
 from df_to_azure.parse_settings import TableParameters
@@ -102,8 +102,9 @@ def run(
 
 def upload_dataset(table):
 
-    if len(table.df) == 0:
-        return logging.info("no new records to upload.")
+    if table.df.empty:
+        logging.info("Data empty, no new records to upload.")
+        sys.exit(1)
 
     if table.method == "create":
         create_schema(table)
@@ -123,14 +124,16 @@ def upload_dataset(table):
         push_to_azure(table)
 
     upload_to_blob(table)
-    logging.info(f"Finished! exported {table.df.shape[0]} records.")
+    logging.info(f"Finished exporting {table.df.shape[0]} records to Azure Blob Storage.")
 
 
 def push_to_azure(table):
     table.df = convert_timedelta_to_seconds(table.df)
     max_str = get_max_str_len(table.df)
+    bigint = check_for_bigint(table.df)
     col_types = column_types(table.df)
-    col_types.update(max_str)
+    for u in [max_str, bigint]:
+        col_types.update(u)
 
     with auth_azure() as con:
         table.df.head(n=0).to_sql(
@@ -148,19 +151,13 @@ def push_to_azure(table):
 def upload_to_blob(table):
     blob_client = create_blob_service_client()
     blob_client = blob_client.get_blob_client(
-        container=os.environ.get("ls_blob_container_name"),
-        blob=f"{table.name}/{table.name}",
+        container="dftoazure",
+        blob=f"{table.name}/{table.name}.csv",
     )
-    with tempfile.TemporaryDirectory(suffix="_df_to_azure") as temp_dir:
-        full_path_to_file = os.path.join(temp_dir, table.name + ".csv")
-        table.df.to_csv(
-            full_path_to_file, index=False, sep="^", quotechar='"', line_terminator="\n"
-        )  # export file to staging
 
-        logging.debug(f"start uploading blob {table.name}...")
-        with open(full_path_to_file, "rb") as data:
-            blob_client.upload_blob(data, overwrite=True)
-        logging.debug(f"finished uploading blob {table.name}!")
+    data = table.df.to_csv(index=False, sep="^", quotechar='"', line_terminator="\n")
+
+    blob_client.upload_blob(data, overwrite=True)
 
 
 def create_schema(table):
@@ -233,11 +230,12 @@ def column_types(df: pd.DataFrame, text_length: int = 255, decimal_precision: in
         dtype("int16"): Integer(),
         dtype("int8"): Integer(),
         pd.Int64Dtype(): Integer(),
-        dtype("float64"): Float(precision=decimal_precision),
-        dtype("float32"): Float(precision=decimal_precision),
-        dtype("float16"): Float(precision=decimal_precision),
+        dtype("float64"): Numeric(precision=18, scale=decimal_precision),
+        dtype("float32"): Numeric(precision=18, scale=decimal_precision),
+        dtype("float16"): Numeric(precision=18, scale=decimal_precision),
         dtype("<M8[ns]"): DateTime(),
         dtype("bool"): Boolean(),
+        pd.BooleanDtype(): Boolean(),
     }
 
     col_types = {
@@ -261,3 +259,19 @@ def get_max_str_len(df):
                 update_dict_len[col] = String(length=None)
 
     return update_dict_len
+
+
+def check_for_bigint(df):
+    ints = df.select_dtypes(include=["int8", "int16", "int32", "int64"])
+    if ints.empty:
+        return {}
+
+    # These are the highest and lowest number
+    # which can be stored in an integer column in SQL.
+    # For numbers out of these bounds, we convert to bigint
+    check = (ints.lt(-2147483648) | ints.gt(2147483647)).any()
+    cols_bigint = check[check].index.tolist()
+
+    update_dict_bigint = {col: BigInteger() for col in cols_bigint}
+
+    return update_dict_bigint
