@@ -9,6 +9,7 @@ from keyvault import secrets_to_environment
 from df_to_azure import df_to_azure, dfs_to_azure
 from df_to_azure.db import auth_azure
 
+
 logging.getLogger("azure.core.pipeline.policies.http_logging_policy").setLevel(logging.WARNING)
 secrets_to_environment(keyvault_name="df-to-azure")
 
@@ -251,8 +252,8 @@ def test_mapping_column_types():
             "Int": [1, 2, 3],
             "Int16": array([1, 2, 3], dtype="int16"),
             "pd_Int64": Series([1, 2, 3], dtype="Int64"),
-            "Float": [4.0, 5.0, 6.0],
-            "Float32": array([4, 4, 6], dtype="float32"),
+            "Float": [4.52, 5.28, 6.71],
+            "Float32": array([4.52, 5.28, 6.71], dtype="float32"),
             "Date": dr1,
             "Timedelta": dr1 - dr2,
             "Bool": [True, False, True],
@@ -264,6 +265,7 @@ def test_mapping_column_types():
         schema="test",
         method="create",
         wait_till_finished=True,
+        pipeline_name="test_column_types",
     )
 
     expected = DataFrame(
@@ -286,14 +288,14 @@ def test_mapping_column_types():
                 "int",
                 "int",
                 "int",
-                "real",
-                "real",
+                "numeric",
+                "numeric",
                 "datetime",
-                "real",
+                "numeric",
                 "bit",
             ],
             "CHARACTER_MAXIMUM_LENGTH": [255, 255, nan, nan, nan, nan, nan, nan, nan, nan],
-            "NUMERIC_PRECISION": [nan, nan, 10, 10, 10, 24, 24, nan, 24, nan],
+            "NUMERIC_PRECISION": [nan, nan, 10, 10, 10, 18, 18, nan, 18, nan],
         }
     )
 
@@ -396,6 +398,41 @@ def test_pipeline_name():
     )
 
 
+def test_empty_dataframe():
+    df = DataFrame()
+
+    with pytest.raises(SystemExit):
+        df_to_azure(
+            df=df,
+            tablename="empty_dataframe",
+            schema="test",
+            method="create",
+            wait_till_finished=True,
+        )
+
+
+def test_convert_bigint():
+    df = DataFrame({"A": [1, 2, -2147483649], "B": [10, 20, 30]})
+
+    df_to_azure(df=df, tablename="bigint", schema="test", wait_till_finished=True)
+
+    query = """
+    SELECT
+        COLUMN_NAME,
+        DATA_TYPE
+    FROM
+        INFORMATION_SCHEMA.COLUMNS
+    WHERE
+        TABLE_NAME = 'bigint';
+    """
+
+    with auth_azure() as con:
+        result = read_sql_query(query, con=con)
+
+    expected = DataFrame({"COLUMN_NAME": ["A", "B"], "DATA_TYPE": ["bigint", "int"]})
+    assert_frame_equal(result, expected)
+
+
 # --- CLEAN UP ----
 def test_clean_up_db():
     tables_dict = {
@@ -419,6 +456,8 @@ def test_clean_up_db():
             "quote_char",
             "append",
             "pipeline_name",
+            "bigint",
+            "bigint_convert",
         ],
     }
 
@@ -437,6 +476,7 @@ if __name__ == "__main__":
     # test_create_category(file_dir_run)
     # test_upsert_category(file_dir_run)
     # test_upsert_id_field_multiple_columns(file_dir_run)
+    # test_mapping_column_types()
     # test_run_multiple(file_dir_run)
     # test_append()
     # test_wrong_method()
@@ -445,6 +485,8 @@ if __name__ == "__main__":
     # test_long_string()
     # test_quote_char()
     # test_pipeline_name()
+    test_empty_dataframe()
+    # test_convert_bigint()
 
     # RUN AS LAST FUNCTION
     test_clean_up_db()
